==> pure-ftpd-1.0.52.tar.gz: pure-ftpd-1.0.52/src/messages_kr.h <==
#define MSG_TLS_CIPHER_FAILED "TLS: Invalid TLSCipherSuite specified '%s'"
#define MSG_TIMEOUT "ð ʰ"
#define MSG_CAPABILITIES " ȯ Ұ"
#define MSG_CLIENT_CLOSED_CNX "Ŭ̾Ʈ  "
#define MSG_CLIENT_READ_ERR "Ŭ̾Ʈ б "
#define MSG_CANT_OPEN_CNX " Ұ"
#define MSG_CANT_CREATE_DATA_SOCKET "   "
#define MSG_DEBUG_CLIENT_IS " ּҴ"
#define MSG_SYNTAX_ERROR_IP "IP ּ   "
#define MSG_PORT_SUCCESSFUL "PORT  "
#define MSG_ONLY_IPV4V6 "IPv4  IPv6   (1,2)"
#define MSG_ONLY_IPV4 "IPv4   (1)"
#define MSG_TIMEOUT_PARSER "ð ʰ"
#define MSG_LINE_TOO_LONG "ʹ "
#define MSG_LOG_OVERFLOW "ڰ ɾ  overflow õ"
#define MSG_GOODBYE "ȳ~ ε %llu / ٿε %llu kb"
#define MSG_DEBUG_COMMAND "ɾ"
#define MSG_IS_YOUR_CURRENT_LOCATION " ġϰ ֽϴ."
#define MSG_NOT_LOGGED_IN "α  ʾҽϴ."
#define MSG_AUTH_UNIMPLEMENTED "  Ҽ "
#define MSG_NO_FILE_NAME "ϸ "
#define MSG_NO_DIRECTORY_NAME "丮 ̸ "
#define MSG_NO_RESTART_POINT " ġ "
#define MSG_ABOR_SUCCESS "ABOR  "
#define MSG_MISSING_ARG " "
#define MSG_GARBAGE_FOUND "ڿ   "
#define MSG_VALUE_TOO_LARGE " ʹ ŭ"
#define MSG_IDLE_TIME " ð %lu ʷ "
#define MSG_SITE_HELP " SITE ɾ ν"
#define MSG_BAD_CHMOD "߸ "
#define MSG_UNKNOWN_EXTENSION " 𸣴 "
#define MSG_XDBG_OK "XDBG  ,  : %d"
#define MSG_UNKNOWN_COMMAND "𸣴 "
#define MSG_TIMEOUT_NOOP "ðʰ (%lu  ۵ )"
#define MSG_TIMEOUT_DATA "ðʰ (%lu   ο ͸  )"
#define MSG_SLEEPING "~  Zzzz..."
#define MSG_ALREADY_LOGGED "̹ α Ǿֽϴ."
#define MSG_ANY_PASSWORD "ƹ нε α "
#define MSG_ANONYMOUS_LOGGED "Anonymous  α"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL " FTP Anonymous  α"
#define MSG_USER_OK " %s OK. ȣ ʿմϴ."
#define MSG_CANT_DO_TWICE " ǿ Ұ մϴ."
#define MSG_UNABLE_SECURE_ANON " anonymous FTP  Ұ"
#define MSG_BANDWIDTH_RESTRICTED "뿪 ѵǾ ֽϴ."
#define MSG_NO_PASSWORD_NEEDED "ƹ нε α "
#define MSG_NOTRUST "˼մϴٸ,    ."
#define MSG_WHOAREYOU " Ű?"
#define MSG_AUTH_FAILED " "
#define MSG_AUTH_TOOMANY "ݺ  "
#define MSG_NO_HOMEDIR "Ȩ 丮   - "
#define MSG_NO_HOMEDIR2 "%s   ʰų ＼ Ҽ "
#define MSG_START_SLASH "/  "
#define MSG_USER_GROUP_ACCESS " %s   ׷쿡  "
#define MSG_FXP_SUPPORT "  FXP  밡 մϴ."
#define MSG_RATIO "/ٿε (%u:%u)  ּ."
#define MSG_CHROOT_FAILED "chroot()  Ҽ "
#define MSG_CURRENT_DIR_IS " 丮: %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "ѵ 丮 %s"
#define MSG_IS_NOW_LOGGED_IN "%s  α"
#define MSG_CANT_CHANGE_DIR "%s 丮 ̵Ҽ "
#define MSG_PATH_TOO_LONG "н ʹ ϴ."
#define MSG_CANT_PASV "IPv6 ӿ PASV  Ҽ ϴ. EPSV  ϼ."
#define MSG_CANT_PASSIVE "нú   "
#define MSG_PORTS_BUSY "  TCP Ʈ Դϴ."
#define MSG_GETSOCKNAME_DATA "   ȮҼ "
#define MSG_GETPEERNAME "  ȮҼ "
#define MSG_INVALID_IP "߸ ּ"
#define MSG_NO_EPSV "EPSV  ϴ IPv6 Ŭ̾Ʈ ϼ."
#define MSG_BAD_PORT "˼, 1024  Ʈδ Ҽ ϴ."
#define MSG_NO_FXP "%s Ʈδ Ҽ ϴ. (%s  밡)"
#define MSG_FXP "FXP  : %s - %s"
#define MSG_NO_DATA_CONN "Ͱ "
#define MSG_ACCEPT_FAILED " ޾Ƶϼ "
#define MSG_ACCEPT_SUCCESS "  "
#define MSG_CNX_PORT_FAILED "%d Ʈ  Ұ"
#define MSG_CNX_PORT "%d Ʈ "
#define MSG_ANON_CANT_MKD "˼մϴ. anonymous  丮  ϴ."
#define MSG_ANON_CANT_RMD "˼մϴ. anonymous  丮 Ҽ ϴ."
#define MSG_ANON_CANT_RENAME "Anonymous   ̵, ϸ  ѵǾ ֽϴ."
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymous  ۹̼  Ұ մϴ."
#define MSG_GLOB_NO_MEMORY "%s  globbing ϴ ޸ ʰ"
#define MSG_PROBABLY_DENIED "(̰ \"㰡 ź\")Դϴ."
#define MSG_GLOB_READ_ERROR "%s  globbing ϴ б  ߻"
#define MSG_GLOB_NO_MATCH "ã  %s / %s"
#define MSG_CHMOD_FAILED "%s  ۹̼  Ұ"
#define MSG_CHMOD_SUCCESS "%s  ۹̼ "
#define MSG_CHMOD_TOTAL_FAILURE "۹̼  Ұմϴ."
#define MSG_ANON_CANT_DELETE "Anonymous    Ҽ ϴ."
#define MSG_ANON_CANT_OVERWRITE "Anonymous  Ⱑ Ұ մϴ."
#define MSG_DELE_FAILED "%s  Ҽ "
#define MSG_DELE_SUCCESS "%s%s%s%s "
#define MSG_DELE_TOTAL_FAILURE "  "
#define MSG_LOAD_TOO_HIGH \
    "ý ϰ %3.2f Դϴ.  ٿε Ұմϴ.\n" \
    "ε  "

#define MSG_OPEN_FAILURE "%s   "
#define MSG_OPEN_FAILURE2 "   ϴ."
#define MSG_STAT_FAILURE " ũ⸦ ˼ ϴ."
#define MSG_STAT_FAILURE2 " 翩θ ȮҼ ϴ."
#define MSG_REST_TOO_LARGE_FOR_FILE "offset %lld   Ұ.  ũ %lld"
#define MSG_REST_RESET "offset 0  "
#define MSG_NOT_REGULAR_FILE "Ϲ ϸ ٿε Ҽ ֽϴ."
#define MSG_NOT_MODERATED \
    "  ٸ anonymous εѰ  Ȯ ľ߸ ٿε Ҽ ֽϴ."

#define MSG_RATIO_DENIAL \
    "˼մϴ.  /ٿ  %u:%u Դϴ.\n" \
     " %llu Kb  εϰ %llu Kb ٿε Ͽϴ.\n" \
    "  ε ּ."
#define MSG_NO_MORE_TO_DOWNLOAD "ٿε   "
#define MSG_WINNER "ǻʹ  ģ̴ Ͼ߸ մϴ!"
#define MSG_KBYTES_LEFT "%.1f kb ٿε"
#define MSG_ABORTED " "
#define MSG_DATA_WRITE_FAILED "͸   ߻"
#define MSG_DATA_READ_FAILED "͸ д  ߻"
#define MSG_MMAP_FAILED "map  ޸𸮿 оϼ "
#define MSG_WRITE_FAILED "   ߻"
#define MSG_TRANSFER_RATE_M "%.3f , %.2f Mb/"
#define MSG_TRANSFER_RATE_K "%.3f , %.2f Kb/"
#define MSG_TRANSFER_RATE_B "%.3f , %.2f b/"
#define MSG_SPACE_FREE_M "밡 ũ 뷮 %.1f Mb"
#define MSG_SPACE_FREE_K "밡 ũ 뷮 %f Kb"
#define MSG_DOWNLOADED "ٿε "
#define MSG_REST_NOT_NUMERIC "REST   ʿ "
#define MSG_REST_ASCII_STRICT "ASCII 忡 Reply marker  0 "
#define MSG_REST_ASCII_WORKAROUND "%lld  . ׷ ASCII "
#define MSG_REST_SUCCESS "%lld  "
#define MSG_SANITY_DIRECTORY_FAILURE " Ұ 丮"
#define MSG_SANITY_FILE_FAILURE " Ұ  ̸: %s"
#define MSG_MKD_FAILURE "丮  "
#define MSG_MKD_SUCCESS "丮  "
#define MSG_RMD_FAILURE "丮 Ҽ "
#define MSG_RMD_SUCCESS "丮  "
#define MSG_TIMESTAMP_FAILURE "time stamp  "
#define MSG_MODE_ERROR "ASCII ̳ʸ 常 "
#define MSG_CREATE_FAILURE "  Ұ"
#define MSG_ABRT_ONLY "ABRT  ε嶧 Ҽ ֽϴ."
#define MSG_UPLOAD_PARTIAL "Ϻκи ε"
#define MSG_REMOVED ""
#define MSG_UPLOADED "ε"
#define MSG_GMTIME_FAILURE " ð ˼ "
#define MSG_TYPE_8BIT_FAILURE "8-bit bytes մϴ.  10 ƴݾƿ?"
#define MSG_TYPE_UNKNOWN "˼  TYPE"
#define MSG_TYPE_SUCCESS " TYPE "
#define MSG_STRU_FAILURE "F(ile)  "
#define MSG_MODE_FAILURE "S(tream) 带 ϼ"
#define MSG_RENAME_ABORT "̸  ۾ "
#define MSG_RENAME_RNFR_SUCCESS "RNFR  -  ,  غ"
#define MSG_FILE_DOESNT_EXIST "˼մϴٸ,  ϴ."
#define MSG_RENAME_ALREADY_THERE "RENAME  -  ̹ մϴ."
#define MSG_RENAME_NORNFR "RNFR Ŀ RNTO "
#define MSG_RENAME_FAILURE "̸/̵ "
#define MSG_RENAME_SUCCESS "  /̵"
#define MSG_NO_SUPERSERVER "pure-ftpd super-server (tcpserver ) ϼ."
#define MSG_NO_FTP_ACCOUNT "'ftp'   "
#define MSG_CONF_ERR " "
#define MSG_NO_VIRTUAL_FILE "   ̸ "
#define MSG_ILLEGAL_THROTTLING "߸  ӵ"
#define MSG_ILLEGAL_TRUSTED_GID "chroot  gid  ߸"
#define MSG_ILLEGAL_USER_LIMIT "߸ ִ "
#define MSG_ILLEGAL_FACILITY "𸣴 facility ̸"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "߸ LDAP  "
#define MSG_ILLEGAL_LOAD_LIMIT "߸  Ѱ"
#define MSG_ILLEGAL_PORTS_RANGE "߸ Ʈ "
#define MSG_ILLEGAL_LS_LIMITS "߸ 'ls' "
#define MSG_ILLEGAL_FORCE_PASSIVE "нú   IP    "
#define MSG_ILLEGAL_RATIO "/ٿ  ߸"
#define MSG_ILLEGAL_UID_LIMIT "uid Ѱ ߸"
#define MSG_ILLEGAL_OPTION "˼   ɼ"
#define MSG_LDAP_MISSING_BASE "LDAP Ͽ LDAPBaseDN  "
#define MSG_LDAP_WRONG_PARMS "߸ LDAP "
#define MSG_NEW_CONNECTION "%s  ο "
#define MSG_WELCOME_TO "!~"
#define MSG_MAX_USERS "%lu  (ִ   ) ̹  ֽϴ. ˼մϴ."
#define MSG_NB_USERS " %u ° Դϴ. ִ %u "
#define MSG_WELCOME_TIME " ð %02d:%02d,  Ʈ %u Դϴ."
#define MSG_ANONYMOUS_FTP_ONLY "anonymous   մϴ."
#define MSG_RATIOS_EVERYONE "  /ٿ   :"
#define MSG_RATIOS_ANONYMOUS "anonymous  /ٿ   :"
#define MSG_RATIOS_RULE "ٿε %u Mb, ε %u Mb"
#define MSG_INFO_IDLE_M "%lu   ƹ͵    ϴ."
#define MSG_INFO_IDLE_S "%lu   ƹ͵    ϴ."
#define MSG_CANT_READ_FILE "[%s]   ϴ."
#define MSG_LS_TRUNCATED "%u   ǥ"
#define MSG_LS_SUCCESS "%u  ġ"
#define MSG_LOGOUT "α׾ƿ."
#define MSG_AUTH_FAILED_LOG "[%s]   "
#define MSG_ILLEGAL_UMASK "߸ umask"
#define MSG_STANDALONE_FAILED "standalone   Ҽ ϴ."
#define MSG_NO_ANONYMOUS_LOGIN "anonymous   ʽϴ."
#define MSG_ANONYMOUS_ANY_PASSWORD "ƹ н峪 "
#define MSG_MAX_USERS_IP "(%lu)   ʰ Ӽ"
#define MSG_ACTIVE_DISABLED "Active   Ұ"
#define MSG_TRANSFER_SUCCESSFUL "  ۵"
#define MSG_NO_DISK_SPACE "ũ 뷮  - ߿ ε ּ"
#define MSG_OUT_OF_MEMORY "޸ ʰ"
#define MSG_ILLEGAL_TRUSTED_IP "߸ ŷڵǴ IP ּ"
#define MSG_NO_ASCII_RESUME "ASCII    ,    ϼ."
#define MSG_UNKNOWN_ALTLOG "߸ α "
#define MSG_ACCOUNT_DISABLED "[%s]  α Ұ :  Ұ"
#define MSG_SQL_WRONG_PARMS "߸ SQL "
#define MSG_ILLEGAL_CONFIG_FILE_SQL "SQL  Ͽ  "
#define MSG_SQL_MISSING_SERVER "SQL  Ͽ  "
#define MSG_SQL_DOWN "SQL  ۵ ʴ° ϴ."
#define MSG_ILLEGAL_QUOTA "߸ Ÿ "
#define MSG_QUOTA_FILES "%llu   (%d%%) - ִ: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes  (%d%%) - ִ: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Ÿ ʰǾ : [%s]   ʾ"
#define MSG_AUTH_UNKNOWN "߸  "
#define MSG_PDB_BROKEN "puredb ε    (Ǵ   ν ) - pure-pw mkdb  õ "
#define MSG_ALIASES_ALIAS "%s %s Ī."
#define MSG_ALIASES_UNKNOWN "   Ī %s."
#define MSG_ALIASES_BROKEN_FILE "ջ Ī "
#define MSG_ALIASES_LIST " Ī  :"
#define MSG_PERUSER_MAX "  %lu  ̻   ʽϴ."
#define MSG_IPV6_OK "  IPv6 ᵵ մϴ."
#define MSG_TLS_INFO "TLS: Enabled %s with %s, %d secret bits cipher"
#define MSG_TLS_WEAK "TLS: Cipher too weak"
#define MSG_TLS_NEEDED "Sorry, cleartext sessions are not accepted on this server.\n" \
    "Please reconnect using TLS security mechanisms."
#define MSG_ILLEGAL_CHARSET "Illegal charset"
#define MSG_TLS_NO_CTX "TLS: Context not found. Exiting."
#define MSG_PROT_OK "Data protection level set to \"%s\""
#define MSG_PROT_PRIVATE_NEEDED "Data connection cannot be opened with this PROT setting."
#define MSG_PROT_UNKNOWN_LEVEL "Protection level %s not understood. Fallback to \"%s\""
#define MSG_PROT_BEFORE_PBSZ "PROT must be preceded by a successful PBSZ command"
#define MSG_WARN_LDAP_USERPASS_EMPTY "LDAP returned no userPassword attribute, check LDAP access rights."
#define MSG_LDAP_INVALID_AUTH_METHOD "Invalid LDAPAuthMethod in the configuration file. Should be 'bind' or 'password'."
#define MSG_INVALID_ARGUMENT "Invalid argument: \"%s\""
#define MSG_READY_TO_PROCEED "Ready to proceed"
#define MSG_ASCII_MODE_UNSUPPORTED "Transfers in ASCII mode are not supported"
#define MSG_ASCII_MODE_WARNING "Warning: client is in ASCII mode - Assuming data is plain text"
#define MSG_DEFERRED_QUIT "Deferring QUIT until transfer completes"

==> pure-ftpd-1.1.0.tar.gz: pure-ftpd-1.1.0/src/messages_kr.h <==
#define MSG_TIMEOUT "ð ʰ"
#define MSG_CAPABILITIES " ȯ Ұ"
#define MSG_CLIENT_CLOSED_CNX "Ŭ̾Ʈ  "
#define MSG_CLIENT_READ_ERR "Ŭ̾Ʈ б "
#define MSG_CANT_OPEN_CNX " Ұ"
#define MSG_CANT_CREATE_DATA_SOCKET "Ÿ   "
#define MSG_DEBUG_CLIENT_IS " ּҴ"
#define MSG_SYNTAX_ERROR_IP "IP ּ   "
#define MSG_PORT_SUCCESSFUL "PORT  "
#define MSG_ONLY_IPV4V6 "IPv4  IPv6  "
#define MSG_ONLY_IPV4 "IPv4  "
#define MSG_TIMEOUT_PARSER "ðʰ"
#define MSG_LINE_TOO_LONG "ʹ "
#define MSG_LOG_OVERFLOW "ڰ ɾ  overflow õ"
#define MSG_GOODBYE "ȳ~ ε %llu / ٿε %llu kb"
#define MSG_DEBUG_COMMAND "ɾ"
#define MSG_IS_YOUR_CURRENT_LOCATION " ġϰ ֽϴ."
#define MSG_NOT_LOGGED_IN "α  ʾҽϴ."
#define MSG_AUTH_UNIMPLEMENTED "  Ҽ "
#define MSG_NO_FILE_NAME "ϸ "
#define MSG_NO_DIRECTORY_NAME "丮 ̸ "
#define MSG_NO_RESTART_POINT " ġ "
#define MSG_ABOR_SUCCESS "ABOR  "
#define MSG_MISSING_ARG " "
#define MSG_GARBAGE_FOUND "ڿ   "
#define MSG_VALUE_TOO_LARGE " ʹ ŭ"
#define MSG_IDLE_TIME " ð %lu ʷ "
#define MSG_SITE_HELP " SITE ɾ ν"
#define MSG_BAD_CHMOD "߸ ۹̼"
#define MSG_UNKNOWN_EXTENSION " 𸣴 "
#define MSG_XDBG_OK "XDBG  ,  : %d"
#define MSG_UNKNOWN_COMMAND "𸣴 "
#define MSG_TIMEOUT_NOOP "ðʰ (%lu  ۵ )"
#define MSG_TIMEOUT_DATA "ðʰ (%lu   ο Ÿ  )"
#define MSG_SLEEPING "~  Zzzz..."
#define MSG_ALREADY_LOGGED "̹ α Ǿֽϴ."
#define MSG_ANY_PASSWORD "ƹ нε α "
#define MSG_ANONYMOUS_LOGGED "Anonymous  α"
#define MSG_ANONYMOUS_LOGGED_VIRTUAL " FTP Anonymous  α"
#define MSG_USER_OK " %s OK. ȣ ʿմϴ."
#define MSG_CANT_DO_TWICE " ǿ Ұ մϴ."
#define MSG_UNABLE_SECURE_ANON " anonymous FTP  Ұ"
#define MSG_BANDWIDTH_RESTRICTED "뿪 ѵǾ ֽϴ."
#define MSG_NO_PASSWORD_NEEDED "ƹ нε α "
#define MSG_NOTRUST "˼մϴٸ,   ."
#define MSG_WHOAREYOU " Ű?"
#define MSG_AUTH_FAILED " "
#define MSG_AUTH_TOOMANY "ݺ  "
#define MSG_NO_HOMEDIR "Ȩ 丮   - "
#define MSG_NO_HOMEDIR2 "%s   ʰų ＼ Ҽ "
#define MSG_START_SLASH "/  "
#define MSG_USER_GROUP_ACCESS " %s   ׷쿡  "
#define MSG_FXP_SUPPORT "  FXP  밡 մϴ."
#define MSG_RATIO "ٿ/ε ( %u:%u )  ּ."
#define MSG_CHROOT_FAILED "chroot()  Ҽ "
#define MSG_CURRENT_DIR_IS " 丮: %s"
#define MSG_CURRENT_RESTRICTED_DIR_IS "ѵ 丮 %s"
#define MSG_IS_NOW_LOGGED_IN "%s  α"
#define MSG_CANT_CHANGE_DIR "%s 丮 ̵Ҽ "
#define MSG_PATH_TOO_LONG "н ʹ ϴ."
#define MSG_CANT_PASV "IPv6 ӿ PASV  Ҽ ϴ. EPSV  ϼ."
#define MSG_CANT_PASSIVE "нú   "
#define MSG_PORTS_BUSY "  TCP Ʈ Դϴ."
#define MSG_GETSOCKNAME_DATA " Ÿ  ȮҼ "
#define MSG_GETPEERNAME "  ȮҼ "
#define MSG_INVALID_IP "߸ ּ"
#define MSG_NO_EPSV "EPSV  ϴ IPv6 Ŭ̾Ʈ ϼ."
#define MSG_BAD_PORT "˼, 1024  Ʈδ Ҽ ϴ."
#define MSG_NO_FXP "%s Ʈδ Ҽ ϴ. (%s  밡)"
#define MSG_FXP "FXP  : %s - %s"
#define MSG_NO_DATA_CONN "Ÿ "
#define MSG_ACCEPT_FAILED " ޾Ƶϼ "
#define MSG_ACCEPT_SUCCESS "Ÿ  "
#define MSG_CNX_PORT_FAILED "%d Ʈ  Ұ"
#define MSG_CNX_PORT "%d Ʈ "
#define MSG_ANON_CANT_MKD "˼մϴ. anonymous  丮  ϴ."
#define MSG_ANON_CANT_RMD "˼մϴ. anonymous  丮 Ҽ ϴ."
#define MSG_ANON_CANT_RENAME "Anonymous   ̵, ϸ  ѵǾ ֽϴ."
#define MSG_ANON_CANT_CHANGE_PERMS "Anonymous  ۹̼  Ұ մϴ."
#define MSG_GLOB_NO_MEMORY "%s  globbing ϴ ޸ ʰ"
#define MSG_PROBABLY_DENIED "(̰ \"㰡 ź\")Դϴ."
#define MSG_GLOB_READ_ERROR "%s  globbing ϴ б  ߻"
#define MSG_GLOB_NO_MATCH "ã  %s / %s"
#define MSG_CHMOD_FAILED "%s  ۹̼  Ұ"
#define MSG_CHMOD_SUCCESS "%s  ۹̼ "
#define MSG_CHMOD_TOTAL_FAILURE "۹̼  Ұմϴ."
#define MSG_ANON_CANT_DELETE "Anonymous    Ҽ ϴ."
#define MSG_ANON_CANT_OVERWRITE "Anonymous  Ⱑ Ұ մϴ."
#define MSG_DELE_FAILED "%s  Ҽ "
#define MSG_DELE_SUCCESS "%s "
#define MSG_DELE_TOTAL_FAILURE "  "
#define MSG_LOAD_TOO_HIGH \
    "ý ϰ %3.2f Դϴ.  ٿε Ұմϴ.\n" \
    "ε  "

#define MSG_OPEN_FAILURE "%s   "
#define MSG_OPEN_FAILURE2 "   ϴ."
#define MSG_STAT_FAILURE " ũ⸦ ˼ ϴ."
#define MSG_STAT_FAILURE2 " 翩θ ȮҼ ϴ."
#define MSG_REST_TOO_LARGE_FOR_FILE "offset %lld   Ұ.  ũ %lld"
#define MSG_REST_RESET "offset 0  "
#define MSG_NOT_REGULAR_FILE "Ϲ ϸ ٿε Ҽ ֽϴ."
#define MSG_NOT_MODERATED \
    "  ٸ anonymous εѰ  Ȯ ľ߸ ٿε Ҽ ֽϴ."

#define MSG_RATIO_DENIAL \
    "˼մϴ.  /ٿ  %u:%u Դϴ.\n" \
	 " %llu Kb  εϰ %llu Kb ٿε Ͽϴ.\n" \
    "  ε ּ."
#define MSG_NO_MORE_TO_DOWNLOAD "ٿεҼ "
#define MSG_WINNER "ǻʹ  ģ̴ Ͼ߸ Դ!"
#define MSG_KBYTES_LEFT "%.1f kb ٿε"
#define MSG_ABORTED " "
#define MSG_DATA_WRITE_FAILED "͸   ߻"
#define MSG_DATA_READ_FAILED "͸ д  ߻"
#define MSG_MMAP_FAILED "map  ޸𸮿 оϼ "
#define MSG_WRITE_FAILED "   ߻"
#define MSG_TRANSFER_RATE_M "%.3f , %.2f Mb/"
#define MSG_TRANSFER_RATE_K "%.3f , %.2f Kb/"
#define MSG_TRANSFER_RATE_B "%.3f , %.2f b/"
#define MSG_SPACE_FREE_M "밡 ũ 뷮 %.1f Mb"
#define MSG_SPACE_FREE_K "밡 ũ 뷮 %f Kb"
#define MSG_DOWNLOADED "ٿε "
#define MSG_REST_NOT_NUMERIC "REST    ʿ "
#define MSG_REST_ASCII_STRICT "ASCII 忡 Reply marker  0 "
#define MSG_REST_ASCII_WORKAROUND "%lld  . ׷ ASCII "
#define MSG_REST_SUCCESS "%lld  "
#define MSG_SANITY_DIRECTORY_FAILURE " Ұ 丮"
#define MSG_SANITY_FILE_FAILURE " Ұ  ̸: %s"
#define MSG_MKD_FAILURE "丮  "
#define MSG_MKD_SUCCESS "丮  "
#define MSG_RMD_FAILURE "丮 Ҽ "
#define MSG_RMD_SUCCESS "丮  "
#define MSG_TIMESTAMP_FAILURE "time stamp  "
#define MSG_MODE_ERROR "ASCII  ̳ʸ 常 "
#define MSG_CREATE_FAILURE "  Ұ"
#define MSG_ABRT_ONLY "ABRT  ε嶧 Ҽ ֽϴ."
#define MSG_UPLOAD_PARTIAL "Ϻκи ε"
#define MSG_REMOVED ""
#define MSG_UPLOADED "ε"
#define MSG_GMTIME_FAILURE " ð ˼ "
#define MSG_TYPE_8BIT_FAILURE "8-bit bytes  մϴ.  10 ƴݾƿ?"
#define MSG_TYPE_UNKNOWN "˼  TYPE"
#define MSG_TYPE_SUCCESS " TYPE "
#define MSG_STRU_FAILURE "F(ile)  "
#define MSG_MODE_FAILURE "S(tream) 带 ϼ"
#define MSG_RENAME_ABORT "̸  ۾ "
#define MSG_RENAME_RNFR_SUCCESS "RNFR  -  ,  غ"
#define MSG_FILE_DOESNT_EXIST "˼մϴٸ,  ϴ."
#define MSG_RENAME_ALREADY_THERE "RENAME  -  ̹ մϴ."
#define MSG_RENAME_NORNFR "RNFR Ŀ RNTO "
#define MSG_RENAME_FAILURE "̸/̵ "
#define MSG_RENAME_SUCCESS "  /̵"
#define MSG_NO_SUPERSERVER "pure-ftpd  super-server (tcpserver ) ϼ."
#define MSG_NO_FTP_ACCOUNT "'ftp'   "
#define MSG_CONF_ERR " "
#define MSG_NO_VIRTUAL_FILE "   ̸ "
#define MSG_ILLEGAL_THROTTLING "߸  ӵ"
#define MSG_ILLEGAL_TRUSTED_GID "chroot  gid  ߸"
#define MSG_ILLEGAL_USER_LIMIT "߸ ִ "
#define MSG_ILLEGAL_FACILITY "𸣴 facility ̸"
#define MSG_ILLEGAL_CONFIG_FILE_LDAP "߸ LDAP  "
#define MSG_ILLEGAL_LOAD_LIMIT "߸  Ѱ"
#define MSG_ILLEGAL_PORTS_RANGE "߸ Ʈ "
#define MSG_ILLEGAL_LS_LIMITS "߸ 'ls' "
#define MSG_ILLEGAL_FORCE_PASSIVE "нú   IP    "
#define MSG_ILLEGAL_RATIO "/ٿ  ߸"
#define MSG_ILLEGAL_UID_LIMIT "uid Ѱ ߸"
#define MSG_ILLEGAL_OPTION "˼   ɼ"
#define MSG_LDAP_MISSING_BASE "LDAP Ͽ LDAPBaseDN  "
#define MSG_LDAP_WRONG_PARMS "߸ LDAP "
#define MSG_NEW_CONNECTION "%s  ο "
#define MSG_WELCOME_TO "!~"
#define MSG_MAX_USERS "%lu  (ִ   ) ̹  ֽϴ. ˼մϴ."
#define MSG_NB_USERS " %d ° Դϴ. ִ %d "
#define MSG_WELCOME_TIME " ð %02d:%02d ̸  ϴ %3.2f,  Ʈ %u Դϴ."
#define MSG_ANONYMOUS_FTP_ONLY "anonymous   մϴ."
#define MSG_RATIOS_EVERYONE "  /ٿ   :"
#define MSG_RATIOS_ANONYMOUS "anonymous  /ٿ   :"
#define MSG_RATIOS_RULE "ٿε %u Mb, ε %u Mb"
#define MSG_INFO_IDLE_M "%lu   ƹ͵    ϴ."
#define MSG_INFO_IDLE_S "%lu   ƹ͵    ϴ."
#define MSG_INFO_CPU_TIME "α׾ƿ - CPU ð: %ld.%03ld "
#define MSG_CANT_READ_FILE "[%s]   ϴ."
#define MSG_LS_TRUNCATED "%u   ǥ"
#define MSG_LS_SUCCESS "%u  ġ"
#define MSG_LOGOUT "α׾ƿ"
#define MSG_AUTH_FAILED_LOG "[%s]   "
#define MSG_ILLEGAL_UMASK "߸ umask"
#define MSG_STANDALONE_FAILED "standalone   Ҽ ϴ."
#define MSG_NO_ANONYMOUS_LOGIN "anonymous   ʽϴ."
#define MSG_ANONYMOUS_ANY_PASSWORD "ƹ н峪 "
#define MSG_MAX_USERS_IP "(%lu)   ʰ Ӽ"
#define MSG_ACTIVE_DISABLED "Active   Ұ"
#define MSG_TRANSFER_SUCCESSFUL "  ۵"
#define MSG_NO_DISK_SPACE "ũ 뷮  - ߿ ε ּ"
#define MSG_OUT_OF_MEMORY "޸ ʰ"
#define MSG_ILLEGAL_TRUSTED_IP "߸ ŷڵǴ IP ּ"
#define MSG_NO_ASCII_RESUME "ASCII    ,    ϼ."
#define MSG_UNKNOWN_ALTLOG "߸ α "
#define MSG_ACCOUNT_DISABLED "[%s]  α Ұ :  Ұ"
#define MSG_SQL_WRONG_PARMS "߸ SQL "
#define MSG_ILLEGAL_CONFIG_FILE_SQL "SQL  Ͽ  "
#define MSG_SQL_MISSING_SERVER "SQL  Ͽ  "
#define MSG_SQL_DOWN "SQL  ۵ ʴ° ϴ."
#define MSG_ILLEGAL_QUOTA "߸ Ÿ "
#define MSG_QUOTA_FILES "%llu   (%d%%) - ִ: %llu files"
#define MSG_QUOTA_SIZE "%llu Kbytes  (%d%%) - ִ: %llu Kb"
#define MSG_QUOTA_EXCEEDED "Ÿ ʰǾ : %s   ʾ"
#define MSG_AUTH_UNKNOWN "߸  "
#define MSG_PDB_BROKEN "puredb ε    (Ǵ   ν ) - pure-pw mkdb  õ "
